repo_name
stringlengths
6
101
path
stringlengths
4
300
text
stringlengths
7
1.31M
geegloirco/geeglo-store
store-server/src/main/java/ir/geeglo/dev/store/business/SecurityBusiness.java
<reponame>geegloirco/geeglo-store package ir.geeglo.dev.store.business; import ir.piana.dev.secure.crypto.CryptoAttribute; import ir.piana.dev.secure.crypto.CryptoMaker; import ir.piana.dev.secure.key.SecretKeyAlgorithm; import ir.piana.dev.secure.key.SecretKeyMaker; import ir.piana.dev.secure.util.Base64Converter; im...
WeiEast/qihaosou
app/src/main/java/com/qihaosou/ui/activity/EnterpriseDetailInfoActivity.java
<reponame>WeiEast/qihaosou<filename>app/src/main/java/com/qihaosou/ui/activity/EnterpriseDetailInfoActivity.java<gh_stars>0 package com.qihaosou.ui.activity; import android.content.Context; import android.content.Intent; import android.graphics.drawable.Drawable; import android.os.Bundle; import android.support.annota...
jinjingbo/fine-uploader
client/js/export.js
<filename>client/js/export.js /* globals define, module, global, qq */ (function() { "use strict"; if (typeof define === "function" && define.amd) { define(function() { return qq; }); } else if (typeof module !== "undefined" && module.exports) { module.exports = qq; ...
raman-bt/autopsy
KeywordSearch/src/org/sleuthkit/autopsy/keywordsearch/ContentHit.java
/* * Autopsy Forensic Browser * * Copyright 2011 Basis Technology Corp. * Contact: carrier <at> sleuthkit <dot> org * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://ww...
infamous19/gerrit
java/com/google/gerrit/extensions/common/GroupInfo.java
<reponame>infamous19/gerrit<filename>java/com/google/gerrit/extensions/common/GroupInfo.java // Copyright (C) 2015 The Android Open Source Project // // Licensed under the Apache License, Version 2.0 (the "License"); // you may not use this file except in compliance with the License. // You may obtain a copy of the Lic...
gminteer/tenpai-buddy
client/src/slices/me.js
import {createSlice} from '@reduxjs/toolkit'; const initialState = {_id: null, email: '', profile: {_id: null, username: ''}}; const reducers = { update(state, {payload}) { return payload; }, }; const slice = createSlice({ name: 'me', initialState, reducers, }); export const {update} = slice.actions; ...
PlexPt/gh4a
app/src/main/java/com/gh4a/resolver/CommitDiffLoadTask.java
package com.gh4a.resolver; import android.content.Intent; import android.support.annotation.VisibleForTesting; import android.support.v4.app.FragmentActivity; import com.gh4a.activities.CommitDiffViewerActivity; import com.gh4a.loader.CommitCommentListLoader; import com.gh4a.loader.CommitLoader; import org.eclipse.e...
chaspy/tfsec
internal/app/tfsec/rules/azure/container/logging_rule.go
package container import ( "github.com/aquasecurity/defsec/rules" "github.com/aquasecurity/defsec/rules/azure/container" "github.com/aquasecurity/tfsec/internal/app/tfsec/block" "github.com/aquasecurity/tfsec/internal/app/tfsec/scanner" "github.com/aquasecurity/tfsec/pkg/rule" ) func init() { scanner.RegisterCh...
civilizeddev/fanuc-focas
src/main/java/fwlib32/in_dsfile.java
package fwlib32; import com.sun.jna.NativeLong; import com.sun.jna.Pointer; import com.sun.jna.Structure; import java.util.Arrays; import java.util.List; /** * This file was autogenerated by <a href="http://jnaerator.googlecode.com/">JNAerator</a>,<br> * a tool written by <a href="http://ochafik.com/"><NAME></a> that...
nikelin/Redshape-AS
ui/ui-bindings/src/main/java/com/redshape/ui/data/bindings/views/DefferedModel.java
/* * Copyright 2012 <NAME> * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable law or agreed to in w...
FMudanyali/libjsdl
src/main/java/org/libsdl/api/filesystem/SdlFilesystem.java
package org.libsdl.api.filesystem; import com.sun.jna.Pointer; import org.libsdl.jna.JnaUtils; import org.libsdl.jna.NativeLoader; public final class SdlFilesystem { public static String SDL_GetBasePath() { Pointer path = NativeFunctions.SDL_GetBasePath(); return JnaUtils.extractStringAndReleaseN...
phatblat/macOSPrivateFrameworks
PrivateFrameworks/PassKitUI/PKAutocompleteViewControllerDelegate-Protocol.h
<filename>PrivateFrameworks/PassKitUI/PKAutocompleteViewControllerDelegate-Protocol.h<gh_stars>10-100 // // Generated by class-dump 3.5 (64 bit). // // class-dump is Copyright (C) 1997-1998, 2000-2001, 2004-2013 by <NAME>. // #import "NSObject.h" @class NSIndexPath, NSView, PKAutocompleteViewController; @pro...
swedenconnect/eidas-eu-mock
EIDAS-Sources-2.5.0-SNAPSHOT-MDSL/EIDAS-SAMLEngine/src/main/java/eu/eidas/auth/engine/core/validator/eidas/EidasResponseValidator.java
/* * Copyright (c) 2019 by European Commission * * Licensed under the EUPL, Version 1.2 or - as soon they will be * approved by the European Commission - subsequent versions of the * EUPL (the "Licence"); * You may not use this work except in compliance with the Licence. * You may obtain a copy of the Lic...
1725136424/gulimall
gulimall-product/src/main/java/site/wanjiahao/gulimall/product/service/CategoryService.java
<filename>gulimall-product/src/main/java/site/wanjiahao/gulimall/product/service/CategoryService.java package site.wanjiahao.gulimall.product.service; import com.baomidou.mybatisplus.extension.service.IService; import site.wanjiahao.common.utils.PageUtils; import site.wanjiahao.gulimall.product.entity.CategoryEntity; ...
uryyyyyyy/scalaSamples
scalikejdbc/build.sbt
name := """scalikejdbcSample""" version := "1.0" scalaVersion := "2.11.7" libraryDependencies ++= Seq( "org.scalikejdbc" %% "scalikejdbc" % "2.2.7", "mysql" % "mysql-connector-java" % "5.1.36", "org.scalikejdbc" %% "scalikejdbc-jsr310" % "2.2.7", "ch.qos.logback" % "logback-classic" % "1.1.3", "org.scalikej...
sgholamian/log-aware-clone-detection
NLPCCd/Camel/1316_2.java
<gh_stars>0 //,temp,sample_5439.java,2,16,temp,sample_1443.java,2,16 //,3 public class xxx { public void dummy_method(){ assertEquals("Batch responses expected", 8, responseParts.size()); assertNotNull(responseParts.get(0).getBody()); final ODataFeed feed = (ODataFeed) responseParts.get(1).getBody(); assertNotNull(feed...
lucyq/jiff
lib/client/protocols/booleans/boolean.js
<reponame>lucyq/jiff<filename>lib/client/protocols/booleans/boolean.js // Generic version of operations module.exports = function (SecretShare) { /** * bitwise-XOR with a constant (BOTH BITS). * @method cxor_bit * @param {number} cst - the constant bit to XOR with (0 or 1). * @return {module:jiff-client~J...
rxmicro/rxmicro
rxmicro-annotation-processor-rest-server/src/test/resources/output/io.rxmicro.examples.validation.server.required/model/$$PrimitiveStringModelModelReader.java
<reponame>rxmicro/rxmicro package io.rxmicro.examples.validation.server.required.model; import io.rxmicro.http.QueryParams; import io.rxmicro.rest.model.HttpModelType; import io.rxmicro.rest.model.PathVariableMapping; import io.rxmicro.rest.server.detail.component.ModelReader; import io.rxmicro.rest.server.detail.mode...
murilloSantana/zip-code-search
domain/src/main/java/com/zipcode/zipcodesearch/usecase/address/chain/ValidZipCodeHandler.java
<filename>domain/src/main/java/com/zipcode/zipcodesearch/usecase/address/chain/ValidZipCodeHandler.java package com.zipcode.zipcodesearch.usecase.address.chain; import com.zipcode.zipcodesearch.entity.Address; import com.zipcode.zipcodesearch.usecase.address.dataprovider.adapter.AddressDataProvider; import org.slf4j.L...
charwliu/msf4j
analytics/msf4j-analytics-common/src/main/java/org/wso2/msf4j/analytics/common/tracing/TraceEvent.java
<reponame>charwliu/msf4j /* * Copyright (c) 2016, WSO2 Inc. (http://www.wso2.org) All Rights Reserved. * * WSO2 Inc. licenses this file to you under the Apache License, * Version 2.0 (the "License"); you may not use this file except * in compliance with the License. * You may obtain a copy of the License at * * ...
guardian/dotcom-rendering
dotcom-rendering/cypress/lib/privacySettingsIframe.js
<gh_stars>100-1000 export const privacySettingsIframe = () => { return cy .get('[src*="https://cdn.privacy-mgmt.com/privacy-manager"]') .its('0.contentDocument.body') .should('not.be.empty') .then(cy.wrap); };
liuyukuai/commons
commons-core/src/main/java/com/itxiaoer/commons/core/util/UUIDUtils.java
package com.itxiaoer.commons.core.util; import com.itxiaoer.commons.core.date.LocalDateTimeUtil; import java.time.LocalDateTime; import java.util.UUID; /** * @author : liuyk */ @SuppressWarnings("unused") public class UUIDUtils { public static String guid() { return LocalDateTimeUtil.format(LocalDateT...
leginee/netbeans
dlight/dlight.remote.impl/test/unit/src/org/netbeans/modules/remote/impl/fs/ListenersParityTestCase.java
/* * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER. * * Copyright 2010 Oracle and/or its affiliates. All rights reserved. * * Oracle and Java are registered trademarks of Oracle and/or its affiliates. * Other names may be trademarks of their respective owners. * * The contents of this file are subject...
HoussemNasri/Logisim-Dark
src/logisim_src/gui/opts/ToolbarList.java
<gh_stars>1-10 /* Copyright (c) 2010, <NAME>. License information is located in the * logisim_src.Main source code and at www.cburch.com/logisim/. */ package logisim_src.gui.opts; import java.awt.Component; import java.awt.Graphics; import java.beans.PropertyChangeEvent; import java.beans.PropertyChangeListener; im...
CembZy/java-bable
concurrent-plus/src/com/concurrent/ch02/forkjoin/recursiveaction/FindFilesAndCopy.java
<filename>concurrent-plus/src/com/concurrent/ch02/forkjoin/recursiveaction/FindFilesAndCopy.java package io.renren.modules; import java.io.*; import java.util.ArrayList; import java.util.Collection; import java.util.List; import java.util.concurrent.ForkJoinPool; import java.util.concurrent.RecursiveAction; /** * 使用...
halotroop2288/consulo
modules/desktop-awt/desktop-ui-laf-impl/src/main/java/consulo/desktop/ui/laf/idea/darcula/DarculaPopupMenuBorder.java
// Copyright 2000-2019 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file. package consulo.desktop.ui.laf.idea.darcula; import com.intellij.ide.ui.laf.intellij.IdeaPopupMenuUI; import com.intellij.ui.Gray; import com.intellij.ui.JBColor; import com.inte...
p455w0rd/EndermanEvolution
src/main/java/p455w0rd/endermanevo/client/particle/ParticleEvolvedEndermanAggroPortal.java
<filename>src/main/java/p455w0rd/endermanevo/client/particle/ParticleEvolvedEndermanAggroPortal.java package p455w0rd.endermanevo.client.particle; import net.minecraft.client.particle.IParticleFactory; import net.minecraft.client.particle.Particle; import net.minecraft.client.renderer.*; import net.minecraft.entity.En...
thiagobfb/jasmine-standalone
spec/andCallTroughSpec.js
<gh_stars>0 describe('Testes do obejto and.callThrough', () => { let calculadora = { somar: function (n1, n2) { return n1 + n2; }, subtrair: function (n1, n2) { return n1 - n2; } }; beforeAll(() => { spyOn(calculadora, 'somar').and.cal...
XuanYuan1122/momole
app/src/main/java/com/moemoe/lalala/presenter/BagContract.java
package com.moemoe.lalala.presenter; import com.moemoe.lalala.model.entity.BagDirEntity; import com.moemoe.lalala.model.entity.BagEntity; import com.moemoe.lalala.model.entity.FileEntity; import com.moemoe.lalala.model.entity.Image; import com.moemoe.lalala.model.entity.ShowFolderEntity; import java.util.ArrayList; ...
npocmaka/Windows-Server-2003
base/fs/utils/ifsutil/src/numset.cxx
<reponame>npocmaka/Windows-Server-2003<filename>base/fs/utils/ifsutil/src/numset.cxx<gh_stars>10-100 #include <pch.cxx> #define _NTAPI_ULIB_ #define _IFSUTIL_MEMBER_ #include "ulib.hxx" #include "ifsutil.hxx" #include "numset.hxx" #include "iterator.hxx" DEFINE_EXPORTED_CONSTRUCTOR( NUMBER_SET, OBJECT, I...
lingyunan0510/VIC
vic/drivers/python/vic/pycompat.py
<reponame>lingyunan0510/VIC # -*- coding: utf-8 -*- import sys PY3 = sys.version_info[0] >= 3 if PY3: basestring = str unicode_type = str bytes_type = bytes def iteritems(d): return iter(d.items()) def itervalues(d): return iter(d.values()) pyrange = range pyzip = zip ...
ctc316/algorithm-python
Lintcode/Ladder_1_Algorithm/09. Data Structure - Interval, Array & Matrix/393. Best Time to Buy and Sell Stock IV.py
<reponame>ctc316/algorithm-python class Solution: """ @param K: An integer @param prices: An integer array @return: Maximum profit """ def maxProfit(self, K, prices): n = len(prices) if n < 2: return 0 # equals to unlimited transactions if K >= n / 2:...
wangcy6/weekly_read
code_reading/oceanbase-master/src/sql/engine/dml/ob_multi_part_delete_op.cpp
/** * Copyright (c) 2021 OceanBase * OceanBase CE is licensed under Mulan PubL v2. * You can use this software according to the terms and conditions of the Mulan PubL v2. * You may obtain a copy of Mulan PubL v2 at: * http://license.coscl.org.cn/MulanPubL-2.0 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BAS...
ochui/recharge-me
recharge/urls.py
from django.contrib import admin from django.urls import path, include from django.contrib.sitemaps.views import sitemap from .sitemaps import StaticViewSitemap, TopicSitemap, StaticAuthViewSitemap, CategorySitemap from .views import LandingView, AboutView, ContactView, PrivacyView, TosView sitemaps = { 'static':...
yamamoto-febc/terraform-provider-rke
rke/provider.go
<gh_stars>100-1000 package rke import ( "github.com/hashicorp/terraform-plugin-sdk/helper/schema" "github.com/hashicorp/terraform-plugin-sdk/terraform" ) // Provider returns a terraform.ResourceProvider. func Provider() terraform.ResourceProvider { return &schema.Provider{ Schema: map[string]*schema.Schema{ "...
robertotambunan/tweather
deliveries/cron.go
<reponame>robertotambunan/tweather package deliveries import ( "context" "log" ) // ActivateWheaterUpdateCron function to activate cron for wheater func (cw *CronWeather) ActivateWheater() { err := cw.weatherUsecase.PostCurrentWeather(context.Background()) if err != nil { log.Println(err) } err = cw.newsUsec...
Brianzchen/flow-typed
definitions/npm/koa-basic-auth_v4.x.x/flow_v0.83.x-/koa-basic-auth_v4.x.x.js
<reponame>Brianzchen/flow-typed<filename>definitions/npm/koa-basic-auth_v4.x.x/flow_v0.83.x-/koa-basic-auth_v4.x.x.js declare module 'koa-basic-auth' { declare type Middleware = ( ctx: any, next: () => Promise<void> ) => Promise<void>; declare module.exports: (opts: {| name: string, pass: string,...
fox91/himan
himan-plugins/source/stability.cpp
#include "stability.h" #include "forecast_time.h" #include "level.h" #include "lift.h" #include "logger.h" #include "numerical_functions.h" #include "plugin_factory.h" #include "stability.cuh" #include "util.h" #include <algorithm> // for std::transform #include "fetcher.h" #include "hitool.h" #include "radon.h" #inc...
ypiel-talend/components
services/components-api-service-rest/src/test/java/org/talend/components/service/rest/configuration/ComponentsRegistrySetupTest.java
package org.talend.components.service.rest.configuration; import static org.hamcrest.MatcherAssert.assertThat; import static org.hamcrest.Matchers.arrayWithSize; import org.junit.Test; public class ComponentsRegistrySetupTest { @Test public void testExtractComponentsUrls() { // checking with a null ...
likianta/depsland
depsland/utils/mklink.py
<filename>depsland/utils/mklink.py<gh_stars>0 import os from os.path import exists from pathlib import Path from lk_logger import lk class T: import typing as t FileExistScheme = t.Literal['error', 'keep', 'overwrite'] List = t.List Optional = t.Optional Path = str Paths = t.List[Path] def ...
Yannic/chromium
third_party/blink/web_tests/http/tests/devtools/sources/debugger-ui/async-call-stack-worker.js
<filename>third_party/blink/web_tests/http/tests/devtools/sources/debugger-ui/async-call-stack-worker.js // Copyright 2017 The Chromium Authors. All rights reserved. // Use of this source code is governed by a BSD-style license that can be // found in the LICENSE file. (async function() { TestRunner.addResult(`Tests...
yunseong/incubator-nemo
compiler/optimizer/src/main/java/org/apache/nemo/compiler/optimizer/pass/compiletime/annotating/DefaultMetricPass.java
/* * Licensed to the Apache Software Foundation (ASF) under one * or more contributor license agreements. See the NOTICE file * distributed with this work for additional information * regarding copyright ownership. The ASF licenses this file * to you under the Apache License, Version 2.0 (the * "License"); you ...
Floating-Island/Java-Exercises-_2018__ES_
Ejercicios/05 - Manejo de colecciones/02/src/bebidas/Bebida.java
package bebidas; public class Bebida { private String marca; public Bebida(String m) { marca = m; } public String queMarca() { return marca; } @Override public String toString() { return "Bebida [marca=" + marca + "]"; } @Override public int hashCode() { final int prime = 31; int result = 1...
Fragmented-World/fragmented-web-ui
src/styles/PointerLink.js
<reponame>Fragmented-World/fragmented-web-ui import styled from 'styled-components' const PointerLink = styled.a` cursor: pointer; ` export default PointerLink
jacadcaps/webkitty
Source/WebCore/svg/SVGRadialGradientElement.cpp
/* * Copyright (C) 2004, 2005, 2006, 2008 <NAME> <<EMAIL>> * Copyright (C) 2004, 2005, 2006, 2007 <NAME> <<EMAIL>> * Copyright (C) 2008 <NAME> <<EMAIL>> * Copyright (C) 2008 <NAME> <<EMAIL>> * Copyright (C) Research In Motion Limited 2010. All rights reserved. * Copyright (C) 2018-2019 Apple Inc. All rights reser...
BearerPipelineTest/google-ctf
2021/quals/pwn-ebpf/healthcheck/exploit.c
<reponame>BearerPipelineTest/google-ctf /* Copyright 2021 Google LLC Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at https://www.apache.org/licenses/LICENSE-2.0 Unless required ...
microsoftgraph/msgraph-beta-sdk-go
models/privileged_role_summary.go
<filename>models/privileged_role_summary.go package models import ( i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91 "github.com/microsoft/kiota-abstractions-go/serialization" ) // PrivilegedRoleSummary type PrivilegedRoleSummary struct { Entity // The number of users that have the role ...
AllaMaevskaya/AliRoot
STEER/STEER/AliCorrQAChecker.h
#ifndef ALICORRQACHECKER_H #define ALICORRQACHECKER_H /* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. * * See cxx source for full Copyright notice */ /* $Id: AliCorrQAChecker.h 27115 2008-07-04 15:12:14Z hristov $ */ /* Checks the quality assurance. By co...
phil-davis/robotframework
atest/testdata/keywords/library_with_keywords_with_dots_in_name.py
<reponame>phil-davis/robotframework class library_with_keywords_with_dots_in_name(object): def get_keyword_names(self): return ['Dots.in.name.in.a.library', 'Multiple...dots . . in . a............row.in.a.library', 'Ending with a dot. In a library.'] def run_keyword(sel...
miladajilian/MimMessenger
submodules/LegacyComponents/LegacyComponents/TGBackdropView.h
<filename>submodules/LegacyComponents/LegacyComponents/TGBackdropView.h<gh_stars>1-10 #import <UIKit/UIKit.h> @interface TGBackdropView : UIView + (TGBackdropView *)viewWithLightNavigationBarStyle; @end
jsmeow/nebluax
src/main/controller/entities/entity/game/combat/shield/shield.js
const { window } = require('../../../../../../options'); const CombatEntity = require('../combat-entity'); const timers = require('../../../../timers/entity-timers'); const update = require('../../../../update/update-entity'); const exception = require('../../../../../../exception/exception'); const emojis = require('e...
mshrutm/javamelody
javamelody-core/src/main/java/net/bull/javamelody/internal/model/SamplingProfiler.java
/* * Copyright 2008-2019 by <NAME> * * This file is part of Java Melody. * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2...
damedia/culture.ru
web/static/mk_exponats/js/exponats.js
$(function(){ $('.el-one').hover(function(){ $(this).addClass('el-one-hovered'); }, function(){ $(this).removeClass('el-one-hovered'); }); var scrollPane, api; $(window).load(function(){ /*var recalcScrollPane = function() { var expMaxNum = 0, expThisNum = 0, expMaxLine; $('.line')...
Git-liuxiaoyu/cloud-hospital-parent
cloud-hospital-parent/cloud-hospital-nacos-parent/worker-service/src/main/java/com/example/workerservice/outlet/dao/mysql/po/OutRoomPo.java
package com.example.workerservice.outlet.dao.mysql.po; public class OutRoomPo { private Long id; private Integer departmentid; private String roomname; private String status; public Long getId() { return id; } public void setId(Long id) { this.id = id; } public...
inorangestylee/lsvmtools
lsvmutils/ext2.h
<filename>lsvmutils/ext2.h<gh_stars>1-10 /* **============================================================================== ** ** LSVMTools ** ** MIT License ** ** Copyright (c) Microsoft Corporation. All rights reserved. ** ** Permission is hereby granted, free of charge, to any person obtaining a copy ** of this...
yeonjuan/editor
src/editor/util/interpolate-functions/makeInterpolateLength.js
import { Length } from "../../unit/Length"; import { makeInterpolateNumber } from "./makeInterpolateNumber"; import { makeInterpolateIdentity } from "./makeInterpolateIdentity"; function getRealAttributeValue (layer, property, value, refType = 'width', refElement = 'parent') { var refObject = null if (refElem...
kosovojs/pywikibot-scripts
prepare.py
file_nakosais = eval(open(r"lv-dumpscan-nakos.txt", "r", encoding='utf-8').read()) thetext = ["* [[{}]]: {}".format(f[0],f[1]) for f in file_nakosais] with open('dfdsfdsfsdfd.log', 'w', encoding='utf-8') as file_W: file_W.write('\n'.join(thetext))
olamy/taglibs-rdc
taglibs-rdc/src/main/java/org/apache/taglibs/rdc/core/BaseModel.java
/* * Licensed to the Apache Software Foundation (ASF) under one or more * contributor license agreements. See the NOTICE file distributed with * this work for additional information regarding copyright ownership. * The ASF licenses this file to You under the Apache License, Version 2.0 * (the "License"); you may ...
midnightbr/Faculdade
java/JARS/hibernate-release-5.6.0.Final/project/hibernate-core/src/test/java/org/hibernate/test/schemaupdate/QuotedTableNameSchemaUpdateTest.java
/* * Hibernate, Relational Persistence for Idiomatic Java * * License: GNU Lesser General Public License (LGPL), version 2.1 or later. * See the lgpl.txt file in the root directory or <http://www.gnu.org/licenses/lgpl-2.1.html>. */ package org.hibernate.test.schemaupdate; import java.io.File; import java.io.IOExc...
tonioshikanlu/tubman-hack
sources/b/l/d/q/f/g/b.java
package b.l.d.q.f.g; import b.e.a.a.a; import b.l.d.q.f.i.v; import java.util.Objects; public final class b extends z { public final v a; /* renamed from: b reason: collision with root package name */ public final String f5060b; public b(v vVar, String str) { Objects.requireNonNull(vVar, "N...
saranshbht/bsc-codes
semester-6/Python Practice/numpyPractice/program4.py
import numpy as np x = np.array([1, 0, 0, 0]) print("Original array:") print(x) print("Test if any of the elements of a given array is non-zero:") print(np.any(x)) x = np.array([0, 0, 0, 0]) print("Original array:") print(x) print("Test if any of the elements of a given array is non-zero:") print(np.any(x))
onmyway133/Runtime-Headers
macOS/10.13/CoreData.framework/NSXPCStoreManagedObjectArchivingToken.h
<gh_stars>10-100 /* Generated by RuntimeBrowser Image: /System/Library/Frameworks/CoreData.framework/Versions/A/CoreData */ @interface NSXPCStoreManagedObjectArchivingToken : NSObject <NSCoding, NSSecureCoding> { NSURL * _managedObjectReferenceURI; } + (BOOL)supportsSecureCoding; - (id)URI; - (void)dealloc; ...
xiaozhu36/alibaba-cloud-sdk-go
services/reid/struct_accurate_overview_detail.go
package reid //Licensed under the Apache License, Version 2.0 (the "License"); //you may not use this file except in compliance with the License. //You may obtain a copy of the License at // //http://www.apache.org/licenses/LICENSE-2.0 // //Unless required by applicable law or agreed to in writing, software //distribu...
hunterBhough/epahomeratingapp-ui
common-ui/js/components/jobs/jobs-search/search-filter-inspection-stage/search-filter-inspection-stage.controller.js
<reponame>hunterBhough/epahomeratingapp-ui import _find from 'lodash/find'; class SearchFilterInspectionStageController { constructor ($stateParams, UI_ENUMS) { 'ngInject'; this.$stateParams = $stateParams; this.param = UI_ENUMS.SEARCH_PARAMS.INSPECTION_STAGE; this.options = Obj...
chengdh/manage-huo-baby
db/migrate/20110125131136_create_journals.rb
# -*- encoding : utf-8 -*- #coding: utf-8 #coding: utf-8 #coding: utf-8 #日记账 class CreateJournals < ActiveRecord::Migration def self.up create_table :journals do |t| t.references :org,:null => false t.date :bill_date,:null => false t.references :user #已结算未汇金额 t.deci...
IBM/suro-oaas
suro-oaas/suro-oaas-redmine/src/main/resources/redmine-mock/app.js
var express = require('express') var bodyParser = require('body-parser') var app = express() // initialise issue Id with 1 (will be incremented) var issueId = 1; // create parser var jsonParser = bodyParser.json() // declare functions to check if values are defined and/or have the right format function isDefined(obj...
sandialabs/avatar
src/array.h
/********************************************************************************** Avatar Tools Copyright (c) 2019, National Technology and Engineering Solutions of Sandia, LLC All rights reserved. Redistribution and use in source and binary forms, with or without modification, are permitted provided that the foll...
smnarayanan/slimbootloader
BootloaderCommonPkg/Library/SpiBlockIoLib/SpiBlockIoLib.c
<gh_stars>1-10 /** @file This file provides some helper functions via run time service support specific to SPI flash device. Copyright (c) 2017, Intel Corporation. All rights reserved.<BR> SPDX-License-Identifier: BSD-2-Clause-Patent **/ #include <Library/BaseLib.h> #include <Library/SpiBlockIoLib....
demurgos/skype-web-reversed
skype/latest/decompiled/fullExperience/rjs$$ui/components/chat/recentItem.js
define("ui/components/chat/recentItem", [ "require", "exports", "module", "constants/components", "text!views/chat/timeline/recentItem.html" ], function (e, t) { t.name = e("constants/components").chat.RECENT_ITEM; t.template = e("text!views/chat/timeline/recentItem.html"); });
johnzupin/VulkanTools
vkconfig/main_gui.cpp
/* * Copyright (c) 2020 Valve Corporation * Copyright (c) 2020 LunarG, Inc. * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unl...
SDF-Bramble/Artifacts-Reloaded
artifactsreloaded/common/components/effects/CAirwalk.java
package archived.artifactsreloaded.common.components.effects; import java.util.List; import java.util.Random; import net.minecraft.entity.Entity; import net.minecraft.entity.player.EntityPlayer; import net.minecraft.item.ItemStack; import net.minecraft.world.World; import archived.artifactsreloaded.common.components...
PieterjanDeconinck/quarkus
devtools/maven/src/main/java/io/quarkus/maven/BuildMojo.java
<filename>devtools/maven/src/main/java/io/quarkus/maven/BuildMojo.java package io.quarkus.maven; import java.io.File; import java.util.List; import java.util.Properties; import org.apache.maven.artifact.Artifact; import org.apache.maven.plugin.AbstractMojo; import org.apache.maven.plugin.MojoExecutionException; impor...
zcdzcdzcd/models
research/morph_net/network_regularizers/flop_regularizer_test.py
<gh_stars>10-100 # Copyright 2018 The TensorFlow Authors All Rights Reserved. # # Licensed under the Apache License, Version 2.0 (the "License"); # you may not use this file except in compliance with the License. # You may obtain a copy of the License at # # http://www.apache.org/licenses/LICENSE-2.0 # # Unless req...
npocmaka/Windows-Server-2003
ds/security/ssr/te/resource.h
<gh_stars>10-100 //{{NO_DEPENDENCIES}} // Microsoft Developer Studio generated include file. // Used by SSRTE.rc // #define IDS_PROJNAME 100 #define IDR_SSRTENGINE 101 #define IDS_TRANSFORM_SUCCEEDED 101 #define IDS_TRANSFORM_FAILED 102 #define IDS_FILEWRIT...
CrazyJ36/c
c/odd-long-numbers.c
<gh_stars>0 /* This shows why some long types need to be formatted properly. */ #include <stdio.h> int main() { // short int, unsigned short int - h short int i = 3; printf( "%hd", i ); // long int or unsigned long int - l long int i = 3; printf( "%ld", i ); // wide characters or strings - l wchar_...
onap/vfc-nfvo-lcm
lcm/workflows/graphflow/tests/graph_tests.py
# Copyright 2018 ZTE Corporation. # # Licensed under the Apache License, Version 2.0 (the "License"); # you may not use this file except in compliance with the License. # You may obtain a copy of the License at # # http://www.apache.org/licenses/LICENSE-2.0 # # Unless required by applicable law or agreed to in ...
Acidburn0zzz/ComputeLibrary
documentation/navtreeindex8.js
var NAVTREEINDEX8 = { "classarm__compute_1_1_c_l_convolution_rectangle.xhtml":[4,0,0,55], "classarm__compute_1_1_c_l_convolution_rectangle.xhtml#aa0b5cdc99cad00d35521aa756365cef2":[4,0,0,55,0], "classarm__compute_1_1_c_l_convolution_rectangle_kernel.xhtml":[4,0,0,56], "classarm__compute_1_1_c_l_convolution_rectangle_ke...
yurijmi/tdlib-ruby
lib/tdlib/client.rb
<gh_stars>0 # Simple client for TDLib. # @example # TD.configure do |config| # config.lib_path = 'path_to_tdlibjson' # config.encryption_key = 'your_encryption_key' # # config.client.api_id = your_api_id # config.client.api_hash = 'your_api_hash' # end # # client = TD::Client.new # # begin # ...
dmarcotte/intellij-community
platform/platform-impl/src/com/intellij/codeStyle/IdeaColorSchemesProvider.java
/* * Copyright 2000-2012 JetBrains s.r.o. * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable law or agre...
lieftsatyamShrivastava/Java_SoftUni
ProgrammingBasics/NestedLoops-Lab/src/SumOfTwoNumbers.java
<filename>ProgrammingBasics/NestedLoops-Lab/src/SumOfTwoNumbers.java import java.util.Scanner; public class SumOfTwoNumbers { public static void main(String[] args) { Scanner scan = new Scanner(System.in); int begin = Integer.parseInt(scan.nextLine()); int end = Integer.parseInt(scan.nextL...
ArthurMaciel95/link-share-react
src/components/clip-board-area/styles.js
<gh_stars>1-10 import styled from "styled-components"; export const ClipBoardAreaStyle = styled.div` border-radius: 25px; max-width: 250px; .btn { height: 40px; } p { display: flex; align-items: center; margin: 0px; padding: 8px 15px; overflow: hidd...
ifyall/zephyr
lib/os/cbprintf_packaged.c
/* * Copyright (c) 2021 BayLibre, SAS * * SPDX-License-Identifier: Apache-2.0 */ #include <errno.h> #include <stdarg.h> #include <stdint.h> #include <string.h> #include <linker/utils.h> #include <sys/cbprintf.h> #include <sys/types.h> #include <sys/util.h> #include <sys/__assert.h> /** * @brief Check if address...
JohannesBuchner/pystrict3
tests/expect-fail23/recipe-83206.py
#!/usr/bin/env python from string import split first_name = split(""" chet <NAME> ethel <NAME> """) last_name = split(""" milquetoast roth bumstead toodles menderchuck """) er = split(""" killer slayer smiter destroyer defenestrator """) p = split(""" of """) adj = split("""very small tiny non-combatant defenseles...
nfwGytautas/GLEngine-v2
OpenGL Engine/src/components/Component.h
#pragma once #include <type_traits> class Entity; struct Component { Entity* entity{ nullptr }; //This method is called after construction of the component virtual void init() {} //This method is called after every update cycle virtual void update(float frameTime) {} //This method is called before every render ...
PublicHealthEngland/data_management_system
lib/schema_browser/category_choice.rb
<filename>lib/schema_browser/category_choice.rb module SchemaBrowser # Build Category Choice nodes if applicable class CategoryChoice include Nodes::Utility include SchemaBrowser::Utility include SchemaBrowser::UtilityCategory attr_accessor :zipfile, :html, :node, :dataset, :version def initial...
UnionInternationalCheminsdeFer/OSDM-Converter
GTM data converter.tests/src/Gtm/converter/tests/TransitSeriesBorderPointTest.java
package Gtm.converter.tests; import org.junit.Before; import org.junit.Test; import org.mockito.InjectMocks; import org.mockito.Mock; import org.mockito.Mockito; import org.mockito.MockitoAnnotations; import Gtm.ConnectionPoint; import Gtm.GTMTool; import Gtm.GtmFactory; import Gtm.Legacy108Station; impo...
villoro/villoro_posts
0005-strings_python/4_string_builtin_functions.py
<reponame>villoro/villoro_posts text = "heLLo world" print(text.upper()) print(text.lower()) print(text.title()) print("-" * 50) text = "\n hello\r\t" print(text.strip()) print(text.lstrip()) print(text.rstrip())
phaazon/lib-ledger-core
ledger-core/src/core/database/query/QueryFilter.cpp
/* * * QueryFilter * ledger-core * * Created by <NAME> on 28/06/2017. * * The MIT License (MIT) * * Copyright (c) 2016 Ledger * * Permission is hereby granted, free of charge, to any person obtaining a copy * of this software and associated documentation files (the "Software"), to deal * in the Software wi...
opensource-assist/fuschia
garnet/bin/metric_broker/config/test/json_reader_test.cc
<reponame>opensource-assist/fuschia // Copyright 2019 The Fuchsia Authors. All rights reserved. // Use of this source code is governed by a BSD-style license that can be // found in the LICENSE file. #include "garnet/bin/metric_broker/config/json_reader.h" #include <algorithm> #include <array> #include <cstdint> #inc...
matfurrier/BambooBSC
core-base/src/com/netsteadfast/greenstep/sys/SysEventLogSupport.java
<gh_stars>100-1000 /* * Copyright 2012-2016 bambooCORE, greenstep of copyright <NAME> * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE...
klueless-io/k_dsl
_/.template/x-r6-app-core-bak/new-rails-32-l-helper.rb
# Log Helper is an internal class that takes care of a lot of the formating of different content types # e.g key/values, lines, progress counters and headings # it is different to the formatter becuase the formatter is used by Rails Logger to change the output stream style and format class LogHelper @progress_sectio...
horta-tech/hera_cms
db/migrate/20201202150007_create_hera_cms_links.rb
<reponame>horta-tech/hera_cms class CreateHeraCmsLinks < ActiveRecord::Migration[6.0] def change create_table :hera_cms_links do |t| t.string :identifier t.string :path t.string :inner_text, default: "" t.string :classes, default: "" t.string :style, default: "" t.timestamps ...
kmsiapps/maplestory_dpm_calc
dpmModule/character/characterTemplate.py
from .characterKernel import ItemedCharacter as ichar from .characterKernel import LinkSkill from ..item import Arcane, Absolab, Empress, RootAbyss, BossAccesory, Default, Else, Meister, Darkness from ..item.ItemKernel import CharacterModifier as MDF from ..item import ItemKernel as it _STORAGE_FOR_EXISTING_TEMPLATE_D...
Killarexe/Negative-N-Forge-Version
src/main/java/net/killarexe/negativen/entity/SlimeNEntity.java
<filename>src/main/java/net/killarexe/negativen/entity/SlimeNEntity.java package net.killarexe.negativen.entity; import net.minecraftforge.registries.ForgeRegistries; import net.minecraftforge.fml.network.NetworkHooks; import net.minecraftforge.fml.network.FMLPlayMessages; import net.minecraftforge.fml.javafmlm...
jorgedc93/backpack
packages/bpk-svgs/dist/js/icons/sm/thumbs-down.js
import React from "react"; export default (({ styles = {}, ...props }) => <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" width="18" height="18" style={{ width: "1.125rem", height: "1.125rem" }} {...props}><path d="M15.75 4v8.104a2.083 2.083 0 0 1-.144.762l-3.087 7.837a.458.458 0 0 1-.423.297 2.846 ...
ljmf00/autopsy
ImageGallery/src/org/sleuthkit/autopsy/imagegallery/actions/RedoAction.java
/* * Autopsy Forensic Browser * * Copyright 2015 Basis Technology Corp. * Contact: carrier <at> sleuthkit <dot> org * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://ww...
JiangJibo/pinpoint
web/src/main/java/com/navercorp/pinpoint/web/dao/mysql/MysqlWebhookDao.java
package com.navercorp.pinpoint.web.dao.mysql; import com.navercorp.pinpoint.web.dao.WebhookDao; import com.navercorp.pinpoint.web.vo.Webhook; import org.mybatis.spring.SqlSessionTemplate; import org.springframework.beans.factory.annotation.Qualifier; import org.springframework.stereotype.Repository; import java.util....
benja-M-1/homebrew-cask
Casks/dusty.rb
cask "dusty" do version "0.7.5" sha256 "9e6cb17530053ffa7ba75bd4fd2b5840dc6508bd1d70166f3e6179ed30f5f721" url "https://github.com/gamechanger/dusty/releases/download/#{version}/dusty.tar.gz" appcast "https://github.com/gamechanger/dusty/releases.atom" name "Dusty" homepage "https://github.com/gamechanger/d...
gcharest/blip
test/unit/redux/actions/async.test.js
<reponame>gcharest/blip /* global chai */ /* global sinon */ /* global describe */ /* global it */ /* global expect */ /* global beforeEach */ /* global before */ /* global afterEach */ /* global after */ /* global context */ import configureStore from 'redux-mock-store'; import thunk from 'redux-thunk'; import tracki...
paulreimer/makerlabs-acm
docs/hid__global__tag__id_8h.js
var hid__global__tag__id_8h = [ [ "TagFormatView", "struct_h_i_d_global_tag_i_d_1_1_tag_format_view.html", "struct_h_i_d_global_tag_i_d_1_1_tag_format_view" ], [ "ParityView", "struct_h_i_d_global_tag_i_d_1_1_parity_view.html", "struct_h_i_d_global_tag_i_d_1_1_parity_view" ], [ "operator==", "group__firmwar...